@@ -33,7 +33,7 @@ Q_OBJECT
 public:
     FileNote(const QString &path, const QString &id);
     void load();
-    void save(const QString &text) Q_DECL_OVERRIDE;
+    void save(const QString &text) override;
 private:
     void fileSystemChanged(const QString &path);
     QString m_path;
@@ -43,7 +43,7 @@ private:
 FileSystemNoteLoader::FileSystemNoteLoader()
 {
     const QString genericDataLocation = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
-    const QString suffix = "plasma_notes";
+    const QString suffix = QStringLiteral("plasma_notes");
     QDir(genericDataLocation).mkdir(suffix);
     m_notesDir = genericDataLocation + QDir::separator() + suffix;
 }
@@ -51,7 +51,7 @@ FileSystemNoteLoader::FileSystemNoteLoader()
 
 QStringList FileSystemNoteLoader::allNoteIds()
 {
-    return m_notesDir.entryList(QStringList {"*.txt"});
+    return m_notesDir.entryList(QStringList {QStringLiteral("*.txt")});
 }
 
 void FileSystemNoteLoader::deleteNoteResources(const QString &id)
@@ -87,7 +87,7 @@ void FileNote::load()
 {
     QFile file(m_path);
     if (file.open(QIODevice::ReadOnly | QIODevice::Text)) {
-        setNoteText(file.readAll());
+        setNoteText(QString::fromUtf8(file.readAll()));
     }
 }
 
